{
    "$graph": [
        {
            "class": "CommandLineTool",
            "id": "#check_station_mismatch.cwl",
            "label": "check_station_mismatch",
            "baseCommand": [
                "python3",
                "compare_station_list.py"
            ],
            "inputs": [
                {
                    "id": "#check_station_mismatch.cwl/check_station_mismatch/msin",
                    "type": {
                        "type": "array",
                        "items": "Directory"
                    },
                    "doc": "Calibrator measurement sets.",
                    "inputBinding": {
                        "position": 0
                    }
                },
                {
                    "id": "#check_station_mismatch.cwl/check_station_mismatch/solset",
                    "type": "File",
                    "doc": "The solution set from the prefactor pipeline."
                },
                {
                    "id": "#check_station_mismatch.cwl/check_station_mismatch/solset_name",
                    "type": [
                        "null",
                        "string"
                    ],
                    "doc": "Name of the solution set.",
                    "default": "vlbi"
                },
                {
                    "id": "#check_station_mismatch.cwl/check_station_mismatch/filter_baselines",
                    "type": [
                        "null",
                        "string"
                    ],
                    "default": "*&",
                    "doc": "Filter constrains for ndppp_prep_target."
                }
            ],
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                },
                {
                    "class": "InitialWorkDirRequirement",
                    "listing": [
                        {
                            "entryname": "compare_station_list.py",
                            "entry": "import sys\nimport json\nimport yaml\nimport os\nfrom compareStationListVLBI import plugin_main as compareStationList\n\nmss = sys.argv[1:]\ntry:\n    inputs = json.loads(r\"\"\"$(inputs)\"\"\")\nexcept:\n    inputs = yaml.loads(r\"\"\"$(inputs)\"\"\")\nh5parmdb = inputs['solset']['path']\nsolset_name = inputs['solset_name']\nfilter = inputs['filter_baselines']\nprint(mss)\n\noutput = compareStationList(mss, \n                            h5parmdb = h5parmdb, \n                            solset_name = solset_name, \n                            filter = filter)\n\nfilter_out = output['filter']\ncwl_output = {\"filter_out\": filter_out}\n\nwith open('./out.json', 'w') as fp:\n    json.dump(cwl_output, fp)\n"
                        }
                    ]
                }
            ],
            "hints": [
                {
                    "dockerPull": "vlbi-cwl:latest",
                    "class": "DockerRequirement"
                }
            ],
            "stdout": "compareStationMismatch.log",
            "stderr": "compareStationMismatch_err.log",
            "outputs": [
                {
                    "id": "#check_station_mismatch.cwl/check_station_mismatch/filter_out",
                    "type": "string",
                    "outputBinding": {
                        "loadContents": true,
                        "glob": "out.json",
                        "outputEval": "$(JSON.parse(self[0].contents).filter_out)"
                    }
                },
                {
                    "id": "#check_station_mismatch.cwl/check_station_mismatch/logfile",
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "outputBinding": {
                        "glob": "compareStationMismatch*.log"
                    }
                }
            ]
        },
        {
            "class": "CommandLineTool",
            "id": "#collectfiles.cwl",
            "label": "CollectFiles",
            "baseCommand": [
                "bash",
                "collect_files.sh"
            ],
            "inputs": [
                {
                    "id": "#collectfiles.cwl/collectfiles/start_directory",
                    "type": [
                        "null",
                        "Directory"
                    ]
                },
                {
                    "id": "#collectfiles.cwl/collectfiles/files",
                    "type": [
                        "File",
                        {
                            "type": "array",
                            "items": [
                                "File",
                                "Directory"
                            ]
                        }
                    ],
                    "inputBinding": {
                        "position": 0
                    }
                },
                {
                    "id": "#collectfiles.cwl/collectfiles/sub_directory_name",
                    "type": "string"
                }
            ],
            "outputs": [
                {
                    "id": "#collectfiles.cwl/collectfiles/dir",
                    "type": "Directory",
                    "outputBinding": {
                        "glob": "$(inputs.start_directory === null ? inputs.sub_directory_name: inputs.start_directory.basename)\n"
                    }
                }
            ],
            "requirements": [
                {
                    "class": "InitialWorkDirRequirement",
                    "listing": [
                        {
                            "entryname": "collect_files.sh",
                            "entry": "#!/bin/bash\nset -e\nBASE_DIR=\"$(inputs.start_directory === null ? \"\" : inputs.start_directory.basename)\"\nSUB_DIR=\"$(inputs.sub_directory_name)\"\nif [ -z \"$BASE_DIR\" ]\nthen\nOUTPUT_PATH=$SUB_DIR\nelse\nOUTPUT_PATH=$BASE_DIR/$SUB_DIR\nfi\necho $OUTPUT_PATH\nmkdir -p $OUTPUT_PATH\ncp -rL $* $OUTPUT_PATH\n",
                            "writable": false
                        }
                    ]
                },
                {
                    "class": "InlineJavascriptRequirement"
                }
            ]
        },
        {
            "class": "CommandLineTool",
            "id": "#concatenate_files.cwl",
            "label": "concatfiles",
            "baseCommand": [
                "bash",
                "bulk_rename.sh"
            ],
            "requirements": [
                {
                    "class": "InitialWorkDirRequirement",
                    "listing": [
                        {
                            "entryname": "bulk_rename.sh",
                            "entry": "#!/bin/bash\nset -e\nFILE_LIST=(\"\\${@}\")\nFILE_PREFIX=$(inputs.file_prefix)\nFILE_SUFFIX=$(inputs.file_suffix === null ? '' : inputs.file_suffix)\ncat \"\\${FILE_LIST[@]}\" > $FILE_PREFIX.$FILE_SUFFIX\n",
                            "writable": false
                        }
                    ]
                },
                {
                    "class": "InlineJavascriptRequirement"
                }
            ],
            "inputs": [
                {
                    "id": "#concatenate_files.cwl/concatfiles/file_list",
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "inputBinding": {
                        "position": 0
                    }
                },
                {
                    "id": "#concatenate_files.cwl/concatfiles/file_prefix",
                    "type": "string"
                },
                {
                    "id": "#concatenate_files.cwl/concatfiles/file_suffix",
                    "type": [
                        "null",
                        "string"
                    ],
                    "default": "log"
                }
            ],
            "outputs": [
                {
                    "id": "#concatenate_files.cwl/concatfiles/output",
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.file_prefix).$(inputs.file_suffix)"
                    }
                }
            ]
        },
        {
            "class": "CommandLineTool",
            "id": "#download_cats.cwl",
            "label": "download_cats",
            "baseCommand": [
                "downloadCats.py"
            ],
            "inputs": [
                {
                    "id": "#download_cats.cwl/download_cats/msin",
                    "type": {
                        "type": "array",
                        "items": "Directory"
                    },
                    "inputBinding": {
                        "position": 0
                    }
                },
                {
                    "id": "#download_cats.cwl/download_cats/lotss_radius",
                    "type": [
                        "null",
                        "float"
                    ],
                    "default": 2.0
                },
                {
                    "id": "#download_cats.cwl/download_cats/lbcs_radius",
                    "type": [
                        "null",
                        "float"
                    ],
                    "default": 2.0
                },
                {
                    "id": "#download_cats.cwl/download_cats/bright_limit_Jy",
                    "type": "float",
                    "default": 5.0
                },
                {
                    "id": "#download_cats.cwl/download_cats/match_tolerance",
                    "type": [
                        "null",
                        "float"
                    ],
                    "default": 5.0
                },
                {
                    "id": "#download_cats.cwl/download_cats/subtract_limit",
                    "type": [
                        "null",
                        "float"
                    ],
                    "default": 0.5
                },
                {
                    "id": "#download_cats.cwl/download_cats/image_limit_Jy",
                    "type": [
                        "null",
                        "float"
                    ],
                    "default": 0.05
                },
                {
                    "id": "#download_cats.cwl/download_cats/continue_no_lotss",
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "default": true
                },
                {
                    "id": "#download_cats.cwl/download_cats/lotss_catalogue",
                    "type": [
                        "null",
                        "File",
                        "string"
                    ],
                    "default": "lotss_catalogue.csv"
                },
                {
                    "id": "#download_cats.cwl/download_cats/lbcs_catalogue",
                    "type": [
                        "null",
                        "File",
                        "string"
                    ],
                    "default": "lbcs_catalogue.csv"
                },
                {
                    "id": "#download_cats.cwl/download_cats/image_catalogue_name",
                    "type": [
                        "null",
                        "string"
                    ],
                    "default": "image_catalogue.csv"
                },
                {
                    "id": "#download_cats.cwl/download_cats/delay_catalogue_name",
                    "type": [
                        "null",
                        "string"
                    ],
                    "default": "delay_catalogue.csv"
                },
                {
                    "id": "#download_cats.cwl/download_cats/subtract_catalogue_name",
                    "type": [
                        "null",
                        "string"
                    ],
                    "default": "subtract_sources.csv"
                }
            ],
            "requirements": [
                {
                    "class": "NetworkAccess",
                    "networkAccess": true
                }
            ],
            "outputs": [
                {
                    "id": "#download_cats.cwl/download_cats/best_delay_catalogue",
                    "type": "File",
                    "outputBinding": {
                        "glob": "best_delay_*.csv"
                    }
                },
                {
                    "id": "#download_cats.cwl/download_cats/logfile",
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "outputBinding": {
                        "glob": "downloadCats*.log"
                    }
                }
            ],
            "hints": [
                {
                    "dockerPull": "vlbi-cwl",
                    "class": "DockerRequirement"
                }
            ],
            "stdout": "downloadCats.log",
            "stderr": "downloadCats_err.log"
        },
        {
            "class": "CommandLineTool",
            "id": "#dp3_make_parset.cwl",
            "label": "make_parset",
            "baseCommand": [
                "cp"
            ],
            "arguments": [
                {
                    "prefix": "",
                    "shellQuote": false,
                    "position": 0,
                    "valueFrom": "input.parset"
                },
                {
                    "prefix": "",
                    "shellQuote": false,
                    "position": 0,
                    "valueFrom": "dp3.parset"
                }
            ],
            "inputs": [
                {
                    "id": "#dp3_make_parset.cwl/make_parset/flag_baselines",
                    "type": [
                        "null",
                        "string"
                    ],
                    "default": "[]",
                    "doc": "flag baseline pattern, eg \"[ CS013HBA*&&* ]\"."
                },
                {
                    "id": "#dp3_make_parset.cwl/make_parset/station_mismatch",
                    "type": [
                        "null",
                        "string"
                    ],
                    "default": "*&",
                    "doc": "Filter of mismatches between solset and MSs."
                },
                {
                    "id": "#dp3_make_parset.cwl/make_parset/solset",
                    "type": "File",
                    "doc": "The solution set from the prefactor pipeline."
                },
                {
                    "id": "#dp3_make_parset.cwl/make_parset/phasesol",
                    "type": [
                        "null",
                        "string"
                    ],
                    "default": "TGSSphase"
                }
            ],
            "outputs": [
                {
                    "id": "#dp3_make_parset.cwl/make_parset/parset",
                    "type": "File",
                    "outputBinding": {
                        "glob": "dp3.parset"
                    }
                }
            ],
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                },
                {
                    "class": "ShellCommandRequirement"
                },
                {
                    "class": "InitialWorkDirRequirement",
                    "listing": [
                        {
                            "entryname": "input.parset",
                            "entry": "steps                               =   [flag,flagamp,filter,applyPA,applybandpass,applyclock,applybeam,applyRM,applyphase,count]\n#\nnumthreads                          =   2\n#\nmsin.datacolumn                     =   DATA\nmsin.baseline                       =   $(inputs.station_mismatch)\n#\nmsout                               =   .\nmsout.storagemanager                =   \"Dysco\"\nmsout.datacolumn                    =   DATA\nmsout.writefullresflag              =   False\n#\nflag.type                           =   preflagger\nflag.baseline                       =   $(inputs.flag_baselines)\n#\nflagamp.type                        =   preflagger\nflagamp.amplmin                     =   1e-30\n#p\nfilter.type                         =   filter\nfilter.baseline                     =   $(inputs.station_mismatch)\nfilter.remove                       =   true\n#\napplyPA.type                        =   applycal\napplyPA.correction                  =   polalign\napplyPA.solset                      =   calibrator\n#\napplybandpass.type                  =   applycal\napplybandpass.correction            =   bandpass\napplybandpass.updateweights         =   true\napplybandpass.solset                =   calibrator\n#\napplyclock.type                     =   applycal\napplyclock.correction               =   clock\napplyclock.solset                   =   calibrator\n#\napplybeam.type                      =   applybeam\napplybeam.usechannelfreq            =   true\napplybeam.updateweights             =   true\n#\napplyRM.type                        =   applycal\napplyRM.correction                  =   RMextract\napplyRM.solset                      =   target\n#\napplyphase.type                     =   applycal\napplyphase.correction               =   $(inputs.phasesol)\napplyphase.solset                   =   target\n#\n"
                        }
                    ]
                }
            ]
        },
        {
            "class": "CommandLineTool",
            "id": "#dp3_prep_target.cwl",
            "label": "dp3_prep_target",
            "baseCommand": "DP3",
            "inputs": [
                {
                    "id": "#dp3_prep_target.cwl/dp3_prep_target/parset",
                    "type": "File",
                    "inputBinding": {
                        "position": -1
                    },
                    "doc": "DP3 parset file."
                },
                {
                    "id": "#dp3_prep_target.cwl/dp3_prep_target/msin",
                    "type": "Directory",
                    "inputBinding": {
                        "position": 0,
                        "prefix": "msin=",
                        "separate": false
                    },
                    "doc": "Input measurement set."
                },
                {
                    "id": "#dp3_prep_target.cwl/dp3_prep_target/msout_name",
                    "type": [
                        "null",
                        "string"
                    ],
                    "default": ".",
                    "inputBinding": {
                        "position": 0,
                        "prefix": "msout=",
                        "separate": false
                    }
                },
                {
                    "id": "#dp3_prep_target.cwl/dp3_prep_target/solset",
                    "type": "File",
                    "doc": "Input solutions file."
                }
            ],
            "arguments": [
                "applyPA.parmdb=$(inputs.solset.path)",
                "applybandpass.parmdb=$(inputs.solset.path)",
                "applyclock.parmdb=$(inputs.solset.path)",
                "applyRM.parmdb=$(inputs.solset.path)",
                "applyphase.parmdb=$(inputs.solset.path)"
            ],
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                }
            ],
            "outputs": [
                {
                    "id": "#dp3_prep_target.cwl/dp3_prep_target/logfile",
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "outputBinding": {
                        "glob": "dp3_prep_target*.log"
                    }
                },
                {
                    "id": "#dp3_prep_target.cwl/dp3_prep_target/msout",
                    "doc": "Output Measurement Set.",
                    "type": "Directory",
                    "outputBinding": {
                        "glob": "$(inputs.msout_name==\".\" ? inputs.msin.basename : inputs.msout_name)"
                    }
                }
            ],
            "hints": [
                {
                    "dockerPull": "vlbi-cwl:latest",
                    "class": "DockerRequirement"
                }
            ],
            "stdout": "dp3_prep_target.log",
            "stderr": "dp3_prep_target_err.log"
        },
        {
            "class": "Workflow",
            "id": "#main",
            "label": "vlbi-setup",
            "inputs": [
                {
                    "id": "#main/msin",
                    "type": {
                        "type": "array",
                        "items": "Directory"
                    }
                },
                {
                    "id": "#main/solset",
                    "type": "File",
                    "doc": "The solution set from the prefactor pipeline."
                },
                {
                    "id": "#main/filter_baselines",
                    "type": [
                        "null",
                        "string"
                    ],
                    "default": "*&"
                },
                {
                    "id": "#main/flag_baselines",
                    "type": [
                        "null",
                        "string"
                    ],
                    "default": "[]"
                },
                {
                    "id": "#main/phasesol",
                    "type": [
                        "null",
                        "string"
                    ],
                    "default": "TGSSphase"
                }
            ],
            "requirements": [
                {
                    "class": "SubworkflowFeatureRequirement"
                },
                {
                    "class": "MultipleInputFeatureRequirement"
                },
                {
                    "class": "ScatterFeatureRequirement"
                }
            ],
            "steps": [
                {
                    "id": "#main/check_station_mismatch",
                    "in": [
                        {
                            "id": "#main/check_station_mismatch/msin",
                            "source": "#main/msin"
                        },
                        {
                            "id": "#main/check_station_mismatch/solset",
                            "source": "#main/solset"
                        },
                        {
                            "id": "#main/check_station_mismatch/filter_baselines",
                            "source": "#main/filter_baselines"
                        }
                    ],
                    "out": [
                        {
                            "id": "#main/check_station_mismatch/filter_out"
                        },
                        {
                            "id": "#main/check_station_mismatch/logfile"
                        }
                    ],
                    "run": "#check_station_mismatch.cwl",
                    "label": "check_station_mismatch"
                },
                {
                    "id": "#main/download_cats",
                    "in": [
                        {
                            "id": "#main/download_cats/msin",
                            "source": "#main/msin"
                        }
                    ],
                    "out": [
                        {
                            "id": "#main/download_cats/best_delay_catalogue"
                        },
                        {
                            "id": "#main/download_cats/logfile"
                        }
                    ],
                    "run": "#download_cats.cwl",
                    "label": "download_cats"
                },
                {
                    "id": "#main/dp3_make_parset",
                    "in": [
                        {
                            "id": "#main/dp3_make_parset/flag_baselines",
                            "source": "#main/flag_baselines"
                        },
                        {
                            "id": "#main/dp3_make_parset/station_mismatch",
                            "source": "#main/check_station_mismatch/filter_out"
                        },
                        {
                            "id": "#main/dp3_make_parset/solset",
                            "source": "#main/solset"
                        },
                        {
                            "id": "#main/dp3_make_parset/phasesol",
                            "source": "#main/phasesol"
                        }
                    ],
                    "out": [
                        {
                            "id": "#main/dp3_make_parset/parset"
                        }
                    ],
                    "run": "#dp3_make_parset.cwl"
                },
                {
                    "id": "#main/prep_target",
                    "in": [
                        {
                            "id": "#main/prep_target/parset",
                            "source": "#main/dp3_make_parset/parset"
                        },
                        {
                            "id": "#main/prep_target/msin",
                            "linkMerge": "merge_flattened",
                            "source": [
                                "#main/msin"
                            ]
                        },
                        {
                            "id": "#main/prep_target/solset",
                            "source": "#main/solset"
                        }
                    ],
                    "out": [
                        {
                            "id": "#main/prep_target/logfiles"
                        },
                        {
                            "id": "#main/prep_target/msout"
                        }
                    ],
                    "run": "#prep_target.cwl",
                    "scatter": "#main/prep_target/msin",
                    "label": "prep_target"
                },
                {
                    "id": "#main/concat_logfiles_prep_target",
                    "label": "concat_logfiles_prep_target",
                    "in": [
                        {
                            "id": "#main/concat_logfiles_prep_target/file_list",
                            "linkMerge": "merge_flattened",
                            "source": [
                                "#main/prep_target/logfiles"
                            ]
                        },
                        {
                            "id": "#main/concat_logfiles_prep_target/file_prefix",
                            "default": "dp3_prep_target"
                        }
                    ],
                    "out": [
                        {
                            "id": "#main/concat_logfiles_prep_target/output"
                        }
                    ],
                    "run": "#concatenate_files.cwl"
                },
                {
                    "id": "#main/save_logfiles",
                    "in": [
                        {
                            "id": "#main/save_logfiles/files",
                            "linkMerge": "merge_flattened",
                            "source": [
                                "#main/check_station_mismatch/logfile",
                                "#main/download_cats/logfile",
                                "#main/concat_logfiles_prep_target/output"
                            ]
                        },
                        {
                            "id": "#main/save_logfiles/sub_directory_name",
                            "default": "logs"
                        }
                    ],
                    "out": [
                        {
                            "id": "#main/save_logfiles/dir"
                        }
                    ],
                    "run": "#collectfiles.cwl",
                    "label": "save_logfiles"
                }
            ],
            "outputs": [
                {
                    "id": "#main/logdir",
                    "outputSource": "#main/save_logfiles/dir",
                    "type": "Directory"
                },
                {
                    "id": "#main/best_delay_cats",
                    "outputSource": "#main/download_cats/best_delay_catalogue",
                    "type": "File"
                },
                {
                    "id": "#main/parset",
                    "outputSource": "#main/dp3_make_parset/parset",
                    "type": "File"
                },
                {
                    "id": "#main/msout",
                    "outputSource": "#main/prep_target/msout",
                    "type": {
                        "type": "array",
                        "items": "Directory"
                    }
                }
            ]
        },
        {
            "class": "Workflow",
            "id": "#prep_target.cwl",
            "label": "prep_target",
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                },
                {
                    "class": "SubworkflowFeatureRequirement"
                },
                {
                    "class": "StepInputExpressionRequirement"
                },
                {
                    "class": "MultipleInputFeatureRequirement"
                },
                {
                    "class": "InitialWorkDirRequirement",
                    "listing": [
                        {
                            "entry": "$(inputs.msin)",
                            "writable": true
                        }
                    ]
                }
            ],
            "inputs": [
                {
                    "id": "#prep_target.cwl/prep_target/parset",
                    "type": "File"
                },
                {
                    "id": "#prep_target.cwl/prep_target/msin",
                    "type": "Directory"
                },
                {
                    "id": "#prep_target.cwl/prep_target/solset",
                    "type": "File"
                }
            ],
            "steps": [
                {
                    "id": "#prep_target.cwl/prep_target/dp3_prep_target",
                    "label": "dp3_prep_target",
                    "in": [
                        {
                            "id": "#prep_target.cwl/prep_target/dp3_prep_target/parset",
                            "source": "#prep_target.cwl/prep_target/parset"
                        },
                        {
                            "id": "#prep_target.cwl/prep_target/dp3_prep_target/msin",
                            "source": "#prep_target.cwl/prep_target/msin"
                        },
                        {
                            "id": "#prep_target.cwl/prep_target/dp3_prep_target/msout_name",
                            "source": "#prep_target.cwl/prep_target/msin",
                            "valueFrom": "$(\"out_\"+self.basename)"
                        },
                        {
                            "id": "#prep_target.cwl/prep_target/dp3_prep_target/solset",
                            "source": "#prep_target.cwl/prep_target/solset"
                        }
                    ],
                    "out": [
                        {
                            "id": "#prep_target.cwl/prep_target/dp3_prep_target/logfile"
                        },
                        {
                            "id": "#prep_target.cwl/prep_target/dp3_prep_target/msout"
                        }
                    ],
                    "run": "#dp3_prep_target.cwl"
                },
                {
                    "id": "#prep_target.cwl/prep_target/concat_logfiles_prep_targ",
                    "label": "concat_logfiles_prep_target",
                    "in": [
                        {
                            "id": "#prep_target.cwl/prep_target/concat_logfiles_prep_targ/file_list",
                            "linkMerge": "merge_flattened",
                            "source": [
                                "#prep_target.cwl/prep_target/dp3_prep_target/logfile"
                            ]
                        },
                        {
                            "id": "#prep_target.cwl/prep_target/concat_logfiles_prep_targ/file_prefix",
                            "default": "dp3_prep_targ"
                        }
                    ],
                    "out": [
                        {
                            "id": "#prep_target.cwl/prep_target/concat_logfiles_prep_targ/output"
                        }
                    ],
                    "run": "#concatenate_files.cwl"
                }
            ],
            "outputs": [
                {
                    "id": "#prep_target.cwl/prep_target/logfiles",
                    "outputSource": [
                        "#prep_target.cwl/prep_target/concat_logfiles_prep_targ/output"
                    ],
                    "type": "File"
                },
                {
                    "id": "#prep_target.cwl/prep_target/msout",
                    "outputSource": [
                        "#prep_target.cwl/prep_target/dp3_prep_target/msout"
                    ],
                    "type": "Directory"
                }
            ]
        }
    ],
    "cwlVersion": "v1.2"
}
